---
name: Feature request
about: Suggest a new feature for `litestar-playwright`
title: "Enhancement: "
labels: enhancement
assignees: "hasansezertasan"
---

# Enhancement: <!-- Feature Name -->

## Feature Description

<!--
Replace this comment with a description of what the feature should do.
Include details such as links to relevant specs or previous discussions.
-->

## Use Case

<!--
Replace this comment with an example of the problem which this feature
would resolve.
-->
